#include <QtGui>

#include "mainwindow.h"
#include "woman.h"
#include "woman_file.h"
#include "dialog.h"


MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
{    
    changedInfo = false;
    woman = new Woman;


    //////////////////////////////////////////////////////////////////////
    //////////////////////////WIDGETS DEFINITINOS/////////////////////////

    labelName     = new QLabel(tr("Hoş geldiniz"));
    label         = new QLabel(tr("Son Dönem Başlangıcı"));
    dateLabel     = new QLabel(tr("Takvim"));
    durationLabel = new QLabel(tr("Dönem Süresi"));
    periotLabel   = new QLabel(tr("Periyot"));

    spinDay     = new  QSpinBox;
    spinMonth   = new  QSpinBox;
    spinYear    = new  QSpinBox;
    spinDuration = new  QSpinBox;
    spinPeriot  = new  QSpinBox;

    showPreviousDateButton = new QPushButton(tr("<<&Önceki"));
    lock_unlockButton  = new QPushButton(tr("Ki&lidi Aç"));
    showNextDateButton = new QPushButton(tr("&Sonraki>>"));

    calendar = new QCalendarWidget;
    calendar->setFirstDayOfWeek(Qt::Monday);

    //////////////////////////END OF WIDGETS DEFINETINOS/////////////////////
    ////////////////////////////////////////////////////////////////////////
    //////////////////////////WIDGETS INITIALIZE///////////////////////////


    lock_unlockButton->setCheckable(true);
    showNextDateButton->setDefault(true);

    spinDay     ->setRange(1,31);
    spinMonth   ->setRange(1,12);
    spinYear    ->setRange(1,9999);
    spinPeriot  ->setRange(1,31);
    spinDuration->setRange(1,31);

    spinDay->setEnabled(false);
    spinMonth->setEnabled(false);
    spinYear->setEnabled(false);
    spinPeriot->setEnabled(false);
    spinDuration->setEnabled(false);

    calendar->setNavigationBarVisible(true);
    calendar->setEnabled(false);

    this->setWindowTitle("Kadın");
    this->setWindowIcon(QIcon("/usr/share/mlm/images/mlm_logo.png"));

    /////////////////////////////END OF WIDGETS INITIALIZE/////////////////////////
    //////////////////////////////////////////////////////////////////////////////




    /////////
    openingControl(QDir::homePath(), woman);
    setOpeningWindow();
    /////////


    //////////////////////////////////////////////////////////////////////////////
    ////////////////////////////////SETTING LAYOUTS//////////////////////////////

    QWidget *cW = new QWidget;  //This is for central Widget
    QVBoxLayout *mainLayout = new QVBoxLayout;
    mainLayout ->addWidget(labelName);

    mainLayout->addSpacing(5);
    mainLayout->addStretch();

    QVBoxLayout *vlout = new QVBoxLayout;

    vlout->addWidget(label);
    QHBoxLayout *hlout = new QHBoxLayout;
    hlout->addWidget(spinDay);
    hlout->addWidget(spinMonth);
    hlout->addWidget(spinYear);
    vlout->addLayout(hlout);     //add hlout to vlout

    hlout = new QHBoxLayout;
    hlout->addWidget(periotLabel);
    hlout->addSpacing(5);
    hlout->addWidget(durationLabel);
    vlout->addSpacing(25);
    vlout->addStretch();
    vlout->addLayout(hlout);

    hlout = new QHBoxLayout;
    hlout->addWidget(spinPeriot);
    hlout->addSpacing(5);
    hlout->addWidget(spinDuration);
    vlout->addStretch();
    vlout->addLayout(hlout);

    vlout->addWidget(lock_unlockButton);
    mainLayout->addLayout(vlout);

    hlout = new QHBoxLayout;
    QVBoxLayout *vvblo = new QVBoxLayout;
    vvblo->addWidget(this->dateLabel);
    vvblo->addWidget(this->calendar);
    hlout ->addLayout(mainLayout);
    hlout->addSpacing(15);
    hlout->addLayout(vvblo);

    QVBoxLayout *vblo = new QVBoxLayout;

    vblo->addWidget(showNextDateButton);
    vblo->addWidget(showPreviousDateButton);
    hlout->addLayout(vblo);

    cW->setLayout(hlout);
    setCentralWidget(cW);

    ///////////////////////////END OF SETTING LAYOUTS/////////////////////////
    /////////////////////////////////////////////////////////////////////////
    /////////////////CALL FUNCTIONS FOR OTHER INITIAL OPERATIONS/////////////
    createActions();
    createMenu();

    ////////////////////////////////SETTING SIGNALS//////////////////////////////

    connect(lock_unlockButton, SIGNAL(clicked()), this, SLOT(lock_unlock()));
    connect(showNextDateButton, SIGNAL(clicked()), this, SLOT(showNextDate()));
    connect(showPreviousDateButton, SIGNAL(clicked()), this, SLOT(showPreviousDate()));

    connect(spinDay, SIGNAL(valueChanged(int)), this, SLOT(changedSpinBoxes()));
    connect(spinMonth, SIGNAL(valueChanged(int)), this, SLOT(changedSpinBoxes()));
    connect(spinYear, SIGNAL(valueChanged(int)), this, SLOT(changedSpinBoxes()));
    connect(spinDuration, SIGNAL(valueChanged(int)), this, SLOT(changedSpinBoxes()));
    connect(spinPeriot, SIGNAL(valueChanged(int)), this, SLOT(changedSpinBoxes()));

    /////////////////////////////END OF SETTING SIGNALS///////////////////////////
    //////////////////////////////////////////////////////////////////////////////
    /////////////////////////////SETTING THEME///////////////////////////////////

    styleMain = this->styleSheet();
    styleButton = this->lock_unlockButton->styleSheet();
    styleLabel = this->label->styleSheet();
    styleSpinbox = this->spinDay->styleSheet();
    styleMenu = this->editMenuBar->styleSheet();
    styleMenuBar = this->menuBar()->styleSheet();

    setTheme();
}

/*****************************************************************/

void MainWindow::createActions(void)
{
    ////////////FileMenuBar Actions////////
    openPersonAction = new QAction(tr("&Aç"), this);
    openPersonAction->setShortcut(QKeySequence::Open);
    QObject::connect(openPersonAction, SIGNAL(triggered()), this, SLOT(openPerson()));

    newPersonAction = new QAction(tr("&Ekle"), this);
    newPersonAction->setShortcut(QKeySequence::New);
    QObject::connect(newPersonAction, SIGNAL(triggered()), this, SLOT(newPerson()));

    removePersonAction = new QAction(tr("&Sil"), this);
    QObject::connect(removePersonAction, SIGNAL(triggered()), this, SLOT(removePerson()));

    closeAction = new QAction(tr("&Çıkış"), this);
    QObject::connect(closeAction, SIGNAL(triggered()), this, SLOT(close()));


    //EditMenuBar Actions
    saveChangeAction = new QAction(tr("&Değişiklikleri Kaydet"), this);
    QObject::connect(saveChangeAction, SIGNAL(triggered()), this, SLOT(save()));
    saveChangeAction->setEnabled(false);

    saveAsDefaultPersonAction = new QAction(tr("&Varsayılan kişi olarak ayarla"), this);
    QObject::connect(saveAsDefaultPersonAction, SIGNAL(triggered()), this, SLOT(saveAsDefault()));

    saveTmpDateAction = new QAction(tr("&Takvimdeki günü kaydet"), this);
    QObject::connect(saveTmpDateAction, SIGNAL(triggered()), this, SLOT(saveTmpDate()));


    //ThemeMenuBar Actions
    defaultTheme = new QAction(tr("&Varsayılan Tema"), this);
    defaultTheme->setData(0);
    QObject::connect(defaultTheme, SIGNAL(triggered()), this, SLOT(callSetTheme()));

    blueTheme = new QAction(tr("&Mavi"), this);
    blueTheme->setData(1);
    QObject::connect(blueTheme, SIGNAL(triggered()), this, SLOT(callSetTheme()));

    redTheme = new QAction(tr("&Kırmızı"), this);
    redTheme->setData(2);
    QObject::connect(redTheme, SIGNAL(triggered()), this, SLOT(callSetTheme()));

    yellowTheme = new QAction(tr("&Sarı"), this);
    yellowTheme->setData(3);
    QObject::connect(yellowTheme, SIGNAL(triggered()), this, SLOT(callSetTheme()));

    pinkTheme = new QAction("&Pembe", this);
    pinkTheme->setData(4);
    QObject::connect(pinkTheme, SIGNAL(triggered()), this, SLOT(callSetTheme()));

}

/*****************************************************************/

void MainWindow::createMenu(void)
{
    fileMenuBar = menuBar()->addMenu(tr("&Kayıt"));
    fileMenuBar ->addAction(openPersonAction);
    fileMenuBar->addAction(newPersonAction);
    fileMenuBar->addAction(removePersonAction);
    fileMenuBar->addSeparator();
    fileMenuBar->addAction(closeAction);

    editMenuBar = menuBar()->addMenu(tr("&Düzenle"));
    editMenuBar->addAction(saveChangeAction);
    editMenuBar->addAction(saveAsDefaultPersonAction);
    editMenuBar->addAction(saveTmpDateAction);

    themeMenuBar = menuBar()->addMenu("&Tema");
    themeMenuBar->addAction(defaultTheme);
    themeMenuBar->addAction(defaultTheme);

    othersTheme = themeMenuBar->addMenu("&Diğer");
    othersTheme->addAction(blueTheme);
    othersTheme->addAction(redTheme);
    othersTheme->addAction(yellowTheme);
    othersTheme->addAction(pinkTheme);


}

/*****************************************************************/

bool MainWindow::newPerson(void)
{
    newPersonDialog dialogg(this);
    int r = dialogg.exec();

    if(r == QDialog::Accepted){

    woman->set_id(getLastID());
    char id[] = "\0\0\0\0\0\0";
    sprintf(id, "%d", woman->get_id());
    QString path = QDir::homePath();
    path.append("/.woman/");
    path.append(id);
    woman->path = path.toUtf8().constData();
    woman->set_all_from_file();
    setSpinBoxesValue();
    return true;
    }
    else
        return false;
}

/*****************************************************************/

void MainWindow::saveAsDefault(void)
{
    int id = checkIsTherePerson();

    woman->defaultPerson = true;
    if(id == woman->get_id()){
        QMessageBox::warning(this, "Uyarı", "Bu kişi zaten varsayılan olarak ayarlı", QMessageBox::Ok);
        return;
    }
    if(id != 0){
        int result = QMessageBox::question(this, "Uyarı", "Varsayılan olarak bir kişi var. Üzerine yazılarak devam edilsin mi?", QMessageBox::Yes, QMessageBox::No);

        if(result == QMessageBox::No){
            woman->defaultPerson = false;
            return;
        }
    }

    setPersonDefault(woman->get_id());
    woman->defaultPerson = true;
}

/*****************************************************************/

void MainWindow::save(void)
{
   bool result = savePerson(woman->get_id(), spinDay->value(), spinMonth->value(), spinYear->value(), spinDuration->value(), spinPeriot->value(), woman->get_name());
   if(result){
        woman->set_all_from_file();
        this->changedInfo = false;
        saveChangeAction->setEnabled(false);

   }
   else
       this->changedInfo = true;

}

/*****************************************************************/

void MainWindow::showNextDate(void)
{
    woman->find_next_date();
    int day, month, year, i, tmp_day, tmp_month, tmp_year;
    day = woman->get_tmp_day();
    tmp_day = day;
    month = woman->get_tmp_month();
    tmp_month = month;
    year = woman->get_tmp_year();
    tmp_year = year;

    for(i = 0; i < woman->get_duration(); ++i){

        QDate date(year , month, day+i);

        if(month == Jan || month == Mar || month == May || month == Jul || month ==Aug || month == Oct || month == Dec){
            if(day+i == 32){
                day = 1;

                ++month;
                if(month == 13){
                    month = 1;
                    ++year;
                }
                date.setDate(year , month, day);
                day = 1-i;
            }
            goto END;
        }

        if(month == Apr || month == Jun || month == Sep || month == Nov){
            if(day+i == 31){
                day = 1;
                ++month;
                date.setDate(year , month, day);
                day = 1-i;
            }
                goto END;
        }

        if(month == Feb){
            if((year % 4) == 0 ){
                if(day+i == 30){
                    day = 1;
                    ++month;
                    date.setDate(year , month, day);
                    day = 1-i;
                }
            }
            else
                if(day+i == 29){
                day = 1;
                ++month;
                date.setDate(year , month, day);
                day = 1-i;
            }

        }

        END:

        calendar->setSelectedDate(date);

        QBrush brush;
        brush.setColor( Qt::blue );
        QTextCharFormat cf = calendar->dateTextFormat( date );
        cf.setBackground( brush );
        cf.setFontItalic(true);
        cf.setFontStrikeOut(true);

        calendar->setDateTextFormat( date, cf );
        woman->set_last_date_to_tmp();


    }
    QDate date(tmp_year , tmp_month, tmp_day);

    calendar->setSelectedDate(date);
}

/*****************************************************************/

void MainWindow::removePerson(void)
{
    removePersonFile(woman);

    int controlCount;
    QString path = QDir::homePath();
    path.append("/.woman/config");
    QFile control(path);
    control.open(QFile::ReadOnly);
    QTextStream streamc(&control);

    streamc >> controlCount >> controlCount;
    if(controlCount == 0){
        control.close();
        woman->set_id(0);
    }
    else
        woman->set_id(-1);
    control.close();
    setOpeningWindow();
}

/*****************************************************************/

void MainWindow::saveTmpDate(void)
{
    QDate date= this->calendar->selectedDate();
    bool result = savePerson(woman->get_id(), date.day(), date.month(), date.year(), spinDuration->value(), spinPeriot->value(), woman->get_name());
    if(result){
         woman->set_all_from_file();
         this->setSpinBoxesValue();
    }
    else
        QMessageBox::critical(this, "Uyarı", "Tarih Kayıt Edilemedi!", QMessageBox::Ok);

}

/*****************************************************************/

void MainWindow::lock_unlock(void)
{
    if(lock_unlockButton->isChecked()){
        spinDay->setEnabled(true);
        spinMonth->setEnabled(true);
        spinYear->setEnabled(true);
        spinPeriot->setEnabled(true);
        spinDuration->setEnabled(true);
        lock_unlockButton->setText("Ki&litle");
    }
    else{
        spinDay->setEnabled(false);
        spinMonth->setEnabled(false);
        spinYear->setEnabled(false);
        spinPeriot->setEnabled(false);
        spinDuration->setEnabled(false);
        lock_unlockButton->setText("Ki&lidi Aç");
    }   
}

/*****************************************************************/

void MainWindow::changedSpinBoxes(void)
{
    if(woman->get_day() != spinDay->value() || woman->get_month() != spinMonth->value() || woman->get_year() != spinYear->value() || \
       woman->get_duration() != spinDuration->value() || woman->get_periot() != spinPeriot->value()){
        changedInfo = true;
        saveChangeAction->setEnabled(true);

    }
    else{
        changedInfo = false;
        saveChangeAction->setEnabled(false);
    }
}

/*****************************************************************/

void MainWindow::closeEvent(QCloseEvent *event)
{
    if(changedInfo){
        int result = QMessageBox::question(this, "Uyarı", "Değişiklikler Kaydedilsin mi?", QMessageBox::Yes, QMessageBox::No, QMessageBox::Cancel);
        if(result == QMessageBox::Yes){
            if(!savePerson(woman->get_id(), spinDay->value(), spinMonth->value(), spinYear->value(), spinDuration->value(), spinPeriot->value(), woman->get_name()))
                QMessageBox::critical(this, "Uyarı", "Bir hata oldu değişiklikler kayıt edilemeyecek!", QMessageBox::Ok);
        }
        if(result == QMessageBox::Cancel)
             event->ignore();
        if(result == QMessageBox::No)
            event->accept();
    }
    else
        event->accept();
}

/*****************************************************************/

void MainWindow::setOpeningWindow()
{
    if((woman->get_id()) == 0){
        if(newPerson())
            return;
        else
            exit(EXIT_SUCCESS);
    }
    if(woman->defaultPerson){
        char idc[] = "\0\0\0\0\0\0";
        sprintf(idc, "%d", woman->get_id());
        QString path = QDir::homePath();
        path.append("/.woman/");
        path.append(idc);
        woman->path = path.toUtf8().constData();
        woman->set_all_from_file();
        setSpinBoxesValue();
    }
    else
        if(!openPerson())
            if(!newPerson())
                exit(EXIT_SUCCESS);


}

/*****************************************************************/

void MainWindow::setSpinBoxesValue(void) //and name label
{

    spinDay->setValue(woman->get_day());
    spinMonth->setValue(woman->get_month());
    spinYear->setValue(woman->get_year());
    spinDuration->setValue(woman->get_duration());
    spinPeriot->setValue(woman->get_periot());

    QString text("<b>Hoş Geldiniz ");
    text.append(woman->get_name());
    text.append("</b>");
    labelName->setText(text);
}

/*****************************************************************/

bool MainWindow::openPerson(void)
{
    bool ok= false;
    int id = 0;
    while(1)
    {
        id = QInputDialog::getInteger(this, "ID", "ID Numaranızı Girin:", 0, 0, 999, 1, &ok);
        if(verifyID(id) || ok == false)
            break;
    }
    if(ok == false)
        return false;

    char idc[] = "\0\0\0\0\0\0";
    sprintf(idc, "%d", id);
    QString path = QDir::homePath();
    path.append("/.woman/");
    path.append(idc);
    woman->set_id(id);
    woman->path = path.toUtf8().constData();
    woman->set_all_from_file();
    woman->defaultPerson = false;

    setSpinBoxesValue();

    return true;
}

/*****************************************************************/

void MainWindow::showPreviousDate(void)
{
    woman->find_previous_date();
    int day, month, year, i, tmp_day, tmp_month, tmp_year;
    day = woman->get_tmp_day();
    tmp_day = day;
    month = woman->get_tmp_month();
    tmp_month = month;
    year = woman->get_tmp_year();
    tmp_year = year;

    for(i = 0; i < woman->get_duration(); ++i){

        QDate date(year , month, day+i);

        if(month == Jan || month == Mar || month == May || month == Jul || month ==Aug || month == Oct || month == Dec){
            if(day+i == 32){
                day = 1;

                ++month;
                if(month == 13){
                    month = 1;
                    ++year;
                }
                date.setDate(year , month, day);
                day = 1-i;
            }
            goto END;
        }

        if(month == Apr || month == Jun || month == Sep || month == Nov){
            if(day+i == 31){
                day = 1;
                ++month;
                date.setDate(year , month, day);
                day = 1-i;
            }
                goto END;
        }

        if(month == Feb){
            if((year % 4) == 0 ){
                if(day+i == 30){
                    day = 1;
                    ++month;
                    date.setDate(year , month, day);
                    day = 1-i;
                }
            }
            else
                if(day+i == 29){
                day = 1;
                ++month;
                date.setDate(year , month, day);
                day = 1-i;
            }

        }

        END:

        calendar->setSelectedDate(date);

        QBrush brush;
        brush.setColor( Qt::blue );
        QTextCharFormat cf = calendar->dateTextFormat( date );
        cf.setBackground( brush );
        cf.setFontItalic(true);
        cf.setFontStrikeOut(true);

        calendar->setDateTextFormat( date, cf );
        woman->set_last_date_to_tmp();


    }
    QDate date(tmp_year , tmp_month, tmp_day);

    calendar->setSelectedDate(date);
}

/*****************************************************************/

void MainWindow::callSetTheme(void)
{
    QAction *action = qobject_cast<QAction *>(sender());
    setTheme(action->data().toInt());
}

/*****************************************************************/

void MainWindow::setTheme(int no)
{
    bool ok = true; //if ok == true; get_theme else set_theme

     if(no == -1)
        get_setTheme(no, ok);

    ok = false;
    switch (no){
    case 0:///defaul theme
         this->setStyleSheet(styleMain);

        //Menus and actions
        fileMenuBar->setStyleSheet (styleMenu);
        editMenuBar->setStyleSheet (styleMenu);
        themeMenuBar->setStyleSheet(styleMenu);
        othersTheme->setStyleSheet (styleMenu);

       this->menuBar()->setStyleSheet(styleMenuBar);


        //labels
        this->label->setStyleSheet        (styleLabel);
        this->labelName->setStyleSheet    (styleLabel);
        this->dateLabel->setStyleSheet    (styleLabel);
        this->durationLabel->setStyleSheet(styleLabel);
        this->periotLabel->setStyleSheet  (styleLabel);

        //SpinBoxes
        this->spinDay->setStyleSheet      (styleSpinbox);
        this->spinMonth->setStyleSheet    (styleSpinbox);
        this->spinYear->setStyleSheet     (styleSpinbox);
        this->spinDuration->setStyleSheet (styleSpinbox);
        this->spinPeriot->setStyleSheet   (styleSpinbox);

        //PushButtons
        this->showNextDateButton->setStyleSheet     (styleButton);
        this->showPreviousDateButton->setStyleSheet (styleButton);
        this->lock_unlockButton->setStyleSheet      (styleButton);


        get_setTheme(no, ok);
        break;


    case 1:////Blue Theme
        this->setStyleSheet("QMainWindow { background: blue }");

        //Menus and actions

        fileMenuBar->setStyleSheet ("QMenu { background: black; color: aqua }");
        editMenuBar->setStyleSheet ("QMenu { background: black; color: aqua }");
        themeMenuBar->setStyleSheet("QMenu { background: black; color: aqua }");
        othersTheme->setStyleSheet ("QMenu { background: black; color: aqua }");

        this->menuBar()->setStyleSheet("QMenuBar { background-color: blue}");

        //labels
        this->label->setStyleSheet        ("QLabel { background: blue; color: black }");
        this->labelName->setStyleSheet    ("QLabel { background: blue; color: black }");
        this->dateLabel->setStyleSheet    ("QLabel { background: blue; color: black }");
        this->durationLabel->setStyleSheet("QLabel { background: blue; color: black }");
        this->periotLabel->setStyleSheet  ("QLabel { background: blue; color: black }");

        //SpinBoxes
        this->spinDay->setStyleSheet      ("QSpinBox {color: aqua; background:black}");
        this->spinMonth->setStyleSheet    ("QSpinBox {color: aqua; background:black}");
        this->spinYear->setStyleSheet     ("QSpinBox {color: aqua; background:black}");
        this->spinDuration->setStyleSheet ("QSpinBox {color: aqua; background:black}");
        this->spinPeriot->setStyleSheet   ("QSpinBox {color: aqua; background:black}");

        //PushButtons
        this->showNextDateButton->setStyleSheet     ("QPushButton {color: aqua; background:blue; border-radius:20px} QPushButton:Pressed {padding-left: 5px; padding-top: 5px;}");
        this->showPreviousDateButton->setStyleSheet ("QPushButton {color: aqua; background:blue; border-radius:20px} QPushButton:Pressed {padding-left: 5px; padding-top: 5px;}");
        this->lock_unlockButton->setStyleSheet      ("QPushButton {color: aqua; background:blue}");


        get_setTheme(no, ok);
        break;


    case 2:////Red Theme
        this->setStyleSheet("QMainWindow { background: red }");

        //Menus and actions

        fileMenuBar->setStyleSheet ("QMenu { background: Tomato; color: mediumblue }");
        editMenuBar->setStyleSheet ("QMenu { background: Tomato; color: mediumblue }");
        themeMenuBar->setStyleSheet("QMenu { background: Tomato; color: mediumblue }");
        othersTheme->setStyleSheet ("QMenu { background: Tomato; color: mediumblue }");

        this->menuBar()->setStyleSheet("QMenuBar { background-color: red}");

        //labels
        this->label->setStyleSheet        ("QLabel { background: red; color: black }");
        this->labelName->setStyleSheet    ("QLabel { background: red; color: black }");
        this->dateLabel->setStyleSheet    ("QLabel { background: red; color: black }");
        this->durationLabel->setStyleSheet("QLabel { background: red; color: black }");
        this->periotLabel->setStyleSheet  ("QLabel { background: red; color: black }");

        //SpinBoxes
        this->spinDay->setStyleSheet      ("QSpinBox {color: mediumblue; background:black}");
        this->spinMonth->setStyleSheet    ("QSpinBox {color: mediumblue; background:black}");
        this->spinYear->setStyleSheet     ("QSpinBox {color: mediumblue; background:black}");
        this->spinDuration->setStyleSheet ("QSpinBox {color: mediumblue; background:black}");
        this->spinPeriot->setStyleSheet   ("QSpinBox {color: mediumblue; background:black}");

        //PushButtons
        this->showNextDateButton->setStyleSheet     ("QPushButton {color: mediumblue; background:red; border-radius:20px} QPushButton:Pressed {padding-left: 5px; padding-top: 5px;}");
        this->showPreviousDateButton->setStyleSheet ("QPushButton {color: mediumblue; background:red; border-radius:20px} QPushButton:Pressed {padding-left: 5px; padding-top: 5px;}");
        this->lock_unlockButton->setStyleSheet      ("QPushButton {color: mediumblue; background:red}");

        get_setTheme(no, ok);
        break;


    case 3:////Yellow Theme
        this->setStyleSheet("QMainWindow { background: yellow }");

        //Menus and actions

        fileMenuBar->setStyleSheet ("QMenu { background: blue; color: brown }");
        editMenuBar->setStyleSheet ("QMenu { background: blue; color: brown }");
        themeMenuBar->setStyleSheet("QMenu { background: blue; color: brown }");
        othersTheme->setStyleSheet ("QMenu { background: blue; color: brown }");

        this->menuBar()->setStyleSheet("QMenuBar { background-color: yellow}");

        //labels
        this->label->setStyleSheet        ("QLabel { background: yellow; color: black }");
        this->labelName->setStyleSheet    ("QLabel { background: yellow; color: black }");
        this->dateLabel->setStyleSheet    ("QLabel { background: yellow; color: black }");
        this->durationLabel->setStyleSheet("QLabel { background: yellow; color: black }");
        this->periotLabel->setStyleSheet  ("QLabel { background: yellow; color: black }");

        //SpinBoxes
        this->spinDay->setStyleSheet      ("QSpinBox {color: brown; background:yellow}");
        this->spinMonth->setStyleSheet    ("QSpinBox {color: brown; background:yellow}");
        this->spinYear->setStyleSheet     ("QSpinBox {color: brown; background:yellow}");
        this->spinDuration->setStyleSheet ("QSpinBox {color: brown; background:yellow}");
        this->spinPeriot->setStyleSheet   ("QSpinBox {color: brown; background:yellow}");

        //PushButtons
        this->showNextDateButton->setStyleSheet     ("QPushButton {color: brown; background:yellow; border-radius:20px} QPushButton:Pressed {padding-left: 5px; padding-top: 5px;}");
        this->showPreviousDateButton->setStyleSheet ("QPushButton {color: brown; background:yellow; border-radius:20px} QPushButton:Pressed {padding-left: 5px; padding-top: 5px;}");
        this->lock_unlockButton->setStyleSheet      ("QPushButton {color: brown; background:yellow}");

        get_setTheme(no, ok);
        break;


    case 4: ////pink Theme
         this->setStyleSheet("QMainWindow { background: pink }");

         //Menus and actions

         fileMenuBar->setStyleSheet ("QMenu { background: purple; color: pink }");
         editMenuBar->setStyleSheet ("QMenu { background: purple; color: pink }");
         themeMenuBar->setStyleSheet("QMenu { background: purple; color: pink }");
         othersTheme->setStyleSheet ("QMenu { background: purple; color: pink }");

         this->menuBar()->setStyleSheet("QMenuBar { background-color: pink}");

         //labels
         this->label->setStyleSheet        ("QLabel { background: pink }");
         this->labelName->setStyleSheet    ("QLabel { background: pink }");
         this->dateLabel->setStyleSheet    ("QLabel { background: pink }");
         this->durationLabel->setStyleSheet("QLabel { background: pink }");
         this->periotLabel->setStyleSheet  ("QLabel { background: pink }");

         this->label->setStyleSheet        ("QLabel { color: purple }");
         this->labelName->setStyleSheet    ("QLabel { color: purple }");
         this->dateLabel->setStyleSheet    ("QLabel { color: purple }");
         this->durationLabel->setStyleSheet("QLabel { color: purple }");
         this->periotLabel->setStyleSheet  ("QLabel { color: purple }");

         //SpinBoxes
         this->spinDay->setStyleSheet     ("QSpinBox { background-color: pink }");
         this->spinMonth->setStyleSheet   ("QSpinBox { background: pink }");
         this->spinYear->setStyleSheet    ("QSpinBox { background: pink }");
         this->spinDuration->setStyleSheet("QSpinBox { background: pink }");
         this->spinPeriot->setStyleSheet  ("QSpinBox { background: pink }");


         this->spinDay->setStyleSheet      ("QSpinBox {color: purple; background:pink}");
         this->spinMonth->setStyleSheet    ("QSpinBox {color: purple; background:pink}");
         this->spinYear->setStyleSheet     ("QSpinBox {color: purple; background:pink}");
         this->spinDuration->setStyleSheet ("QSpinBox {color: purple; background:pink}");
         this->spinPeriot->setStyleSheet   ("QSpinBox {color: purple; background:pink}");

         //PushButtons
         this->showNextDateButton->setStyleSheet     ("QPushButton {color: purple; background:pink; border-radius:20px} QPushButton:Pressed {padding-left: 5px; padding-top: 5px;}");
         this->showPreviousDateButton->setStyleSheet ("QPushButton {color: purple; background:pink; border-radius:20px} QPushButton:Pressed {padding-left: 5px; padding-top: 5px;}");
         this->lock_unlockButton->setStyleSheet      ("QPushButton {color: purple; background:pink}");


        get_setTheme(no, ok);
        break;
    }
}

/*****************************************************************/
